Renga Command Line — Renga 0.1.0.dev20171123 documentation

Join us on GitHub

# Renga Command Line

The base command for interacting with the Renga platform.

## `renga` (base command)

To list the available commands, either run `renga` with no parameters or execute `renga help`:

    $ renga help
    Usage: renga [OPTIONS] COMMAND [ARGS]...

    Check common Renga commands used in various situations.

    Options:
      --version            Print version number.
      --config PATH        Location of client config files.
      --config-path        Print application config path.
      --path <path>        Location of a Renga repository.  [default: .]
      --renga-home <path>  Location of Renga directory.  [default: .renga]
      -h, --help           Show this message and exit.

    Commands:
      # [...]

### Configuration files

Depending on your system, you may find the configuration files used by Renga command line in a different folder. By default, the following rules are used:

MacOS:
  `~/Library/Application Support/Renga`
Unix:
  `~/.config/renga`
Windows:
  `C:\Users\<user>\AppData\Roaming\Renga`

If in doubt where to look for the configuration file, you can display its path by running `renga --config-path`.

You can specify a different location via the `RENGA_CONFIG` environment variable or the `--config` command line option. If both are specified, then the `--config` option value is used. For example:

    $ renga --config ~/renga/config/ init

instructs Renga to store the configuration files in your `~/renga/config/` directory when running the `init` command.

## `renga init`

Create an empty Renga project or reinitialize an existing one.

### Starting a Renga project

If you have an existing directory which you want to turn into a Renga project, you can type:

    $ cd ~/my_project
    $ renga init

or:

    $ renga init ~/my_project

This creates a new subdirectory named `.renga` that contains all the necessary files for managing the project configuration.

## `renga datasets`

Work with datasets in the current repository.

### Manipulating datasets

Creating an empty dataset inside a Renga project:

    $ renga dataset create my-dataset

Adding data to the dataset:

    $ renga dataset add my-dataset http://data-url

This will copy the contents of `data-url` to the dataset and add it to the dataset metadata.

## `renga run`

Track provenance of data created by executing programs.

## `renga log`

Show provenance of data created by executing programs.

## `renga workflow`

Workflow operations.